==> 0.1.3.zip: tourplaner/src/tourplaner/viewmodels/ViewModel.java <==
package tourplaner.viewmodels;

import javafx.collections.FXCollections;
import javafx.collections.ObservableList;
import javafx.scene.control.Alert;
import javafx.scene.control.TextInputDialog;
import tourplaner.business.AlertHelper;
import tourplaner.business.LogHelper;
import tourplaner.business.TourPlaner;
import tourplaner.object.Tour;
import java.util.Optional;
import java.util.concurrent.atomic.AtomicReference;

public class ViewModel {
    private final ObservableList<Tour> tourData = FXCollections.observableArrayList(new Tour("Test 1", "120", "json dings", 22.3, "Wien", "Graz"),new Tour("Test 2", "210", "json dings", 42.3, "Da", "Dort"));
    private final ObservableList<String> tourNamen = FXCollections.observableArrayList("Test 1", "Test 2");
    //private final ObservableList<Tour> selectedTour = FXCollections.observableArrayList();
    private Tour selectedTour;
    private String neueTourName, neueTourStart, neueTourZiel;

    /**
     * Fügt eine neue Tour hinzu
     */
    public void addTour(){
        while(this.neueTourName == null) {
            this.neueTourName = AlertHelper.inputText("Tourname", "Bitte geben Sie den Namen der Tour an!", "Name:");
            if (getTour(this.neueTourName) != null) {
                AlertHelper.warn("ACHTUNG", "Name bereits vergeben!", "Der Name '"+ this.neueTourName +"' ist bereits vergeben, bitte verwenden Sie einen andern!");
                this.neueTourName = null;
            }
        }
        while(this.neueTourStart == null){
            this.neueTourStart = AlertHelper.inputText("Tour Startpunkt", "Bitte geben Sie den Startpunkt der Tour an!", "Startpunkt: ");
        }
        while(this.neueTourZiel == null){
            this.neueTourZiel = AlertHelper.inputText("Tour zielpunkt", "Bitte geben Sie den Zielpunkt der Tour an!", "Zielpunkt: ");
        }
        if (getTour(this.neueTourName) == null) {
            tourData.add(new Tour(this.neueTourName, "TBD", "TBD", 0, this.neueTourStart, this.neueTourZiel));
            tourNamen.add(this.neueTourName);
        }
        this.neueTourStart = null;
        this.neueTourZiel = null;
        this.neueTourName = null;
    }

    /**
     * Holt das Tourobjekt anhand des Namens
     * @param tourname Name der Tour
     * @return Gefundene Tour
     */
    public Tour getTour(String tourname){
        AtomicReference<Tour> returnTour = new AtomicReference<>();
        tourData.forEach(s -> {
            if(s.getName().equals(tourname)){
                returnTour.set(s);
            }
        });
        return returnTour.get();
    }

    public void selectTour(String tourname){
        this.selectedTour = getTour(tourname);
//        this.selectedTour.removeIf(s -> true);//Alle deselect
//        this.selectedTour.add(getTour(tourname));
    }

    public Tour getSelectedTour() {
        return selectedTour;
    }

    public String getNeueTourZiel() {
        return neueTourZiel;
    }

    public void setNeueTourZiel(String neueTourZiel) {
        this.neueTourZiel = neueTourZiel;
    }

    public ObservableList<String> getTourNamen() {
        return tourNamen;
    }

    public String getNeueTourName() {
        return neueTourName;
    }

    public void setNeueTourName(String neueTourName) {
        this.neueTourName = neueTourName;
    }

    public String getNeueTourStart() {
        return neueTourStart;
    }

    public void setNeueTourStart(String neueTourStart) {
        this.neueTourStart = neueTourStart;
    }

    public ObservableList<Tour> getTourData() {
        return tourData;
    }

    /**
     * Entfernt eine Tour anhand der ausgewählten Tour
     */
    public void delTour(){
        try {
            String tourname = this.selectedTour.getName();
            tourData.removeIf(s -> s.getName().equals(tourname));
            tourNamen.removeIf(s -> s.equals(tourname));
        }catch (NullPointerException e){
            LogHelper.error("Keine Tour ausgewählt!", "ViewModel -> DelTour");
            AlertHelper.warn("ACHTUNG", "Keine Tour ausgewählt!", "Bitte wählen Sie zuerst eine Tour aus, bevor Sie auf löschen klicken!");
        }
    }

    /**
     * Sucht eine Tour
     */
    public void suche(String suchString){

    }
}

==> 0.1.4.zip: tourplaner/src/tourplaner/viewmodels/ViewModel.java <==
package tourplaner.viewmodels;

import javafx.collections.FXCollections;
import javafx.collections.ObservableList;
import javafx.scene.control.Alert;
import javafx.scene.control.TextInputDialog;
import tourplaner.business.AlertHelper;
import tourplaner.business.ConfigHelper;
import tourplaner.business.LogHelper;
import tourplaner.business.TourPlaner;
import tourplaner.object.Tour;
import java.util.Optional;
import java.util.concurrent.atomic.AtomicReference;

public class ViewModel {
    private final ObservableList<Tour> tourData = FXCollections.observableArrayList(new Tour("Test 1", "120", "json dings", 22.3, "Wien", "Graz"),new Tour("Test 2", "210", "json dings", 42.3, "Da", "Dort"));
    private final ObservableList<String> tourNamen = FXCollections.observableArrayList("Test 1", "Test 2");
    //private final ObservableList<Tour> selectedTour = FXCollections.observableArrayList();
    private Tour selectedTour;
    private String neueTourName, neueTourStart, neueTourZiel;

    /**
     * Fügt eine neue Tour hinzu
     */
    public void addTour(){
        while(this.neueTourName == null) {
            this.neueTourName = AlertHelper.inputText(ConfigHelper.getIniString(ConfigHelper.getStandartConfig(), "langde", "tournametitle"),
                    ConfigHelper.getIniString(ConfigHelper.getStandartConfig(), "langde", "tournameheader"),
                    ConfigHelper.getIniString(ConfigHelper.getStandartConfig(), "langde", "tournamemsg"));
            if (getTour(this.neueTourName) != null) {
                AlertHelper.warn(ConfigHelper.getIniString(ConfigHelper.getStandartConfig(), "langde", "achtung"),
                        ConfigHelper.getIniString(ConfigHelper.getStandartConfig(), "langde", "namevergebenheader"),
                        ConfigHelper.getIniString(ConfigHelper.getStandartConfig(), "langde", "namevergebenmsg1")
                                + this.neueTourName +
                                ConfigHelper.getIniString(ConfigHelper.getStandartConfig(), "langde", "namevergebenmsg2"));
                this.neueTourName = null;
            }
        }
        while(this.neueTourStart == null){
            this.neueTourStart = AlertHelper.inputText(ConfigHelper.getIniString(ConfigHelper.getStandartConfig(), "langde", "startpunkttitle"),
                    ConfigHelper.getIniString(ConfigHelper.getStandartConfig(), "langde", "startpunktheader"),
                    ConfigHelper.getIniString(ConfigHelper.getStandartConfig(), "langde", "startpunktmsg"));
        }
        while(this.neueTourZiel == null){
            this.neueTourZiel = AlertHelper.inputText(ConfigHelper.getIniString(ConfigHelper.getStandartConfig(), "langde", "zielpunkttitle"),
                    ConfigHelper.getIniString(ConfigHelper.getStandartConfig(), "langde", "zielpunktheader"),
                    ConfigHelper.getIniString(ConfigHelper.getStandartConfig(), "langde", "zielpunktmsg"));
        }
        if (getTour(this.neueTourName) == null) {
            tourData.add(new Tour(this.neueTourName, "TBD", "TBD", 0, this.neueTourStart, this.neueTourZiel));
            tourNamen.add(this.neueTourName);
        }
        this.neueTourStart = null;
        this.neueTourZiel = null;
        this.neueTourName = null;
    }

    /**
     * Holt das Tourobjekt anhand des Namens
     * @param tourname Name der Tour
     * @return Gefundene Tour
     */
    public Tour getTour(String tourname){
        AtomicReference<Tour> returnTour = new AtomicReference<>();
        tourData.forEach(s -> {
            if(s.getName().equals(tourname)){
                returnTour.set(s);
            }
        });
        return returnTour.get();
    }

    public void selectTour(String tourname){
        this.selectedTour = getTour(tourname);
//        this.selectedTour.removeIf(s -> true);//Alle deselect
//        this.selectedTour.add(getTour(tourname));
    }

    public Tour getSelectedTour() {
        return selectedTour;
    }

    public String getNeueTourZiel() {
        return neueTourZiel;
    }

    public void setNeueTourZiel(String neueTourZiel) {
        this.neueTourZiel = neueTourZiel;
    }

    public ObservableList<String> getTourNamen() {
        return tourNamen;
    }

    public String getNeueTourName() {
        return neueTourName;
    }

    public void setNeueTourName(String neueTourName) {
        this.neueTourName = neueTourName;
    }

    public String getNeueTourStart() {
        return neueTourStart;
    }

    public void setNeueTourStart(String neueTourStart) {
        this.neueTourStart = neueTourStart;
    }

    public ObservableList<Tour> getTourData() {
        return tourData;
    }

    /**
     * Entfernt eine Tour anhand der ausgewählten Tour
     */
    public void delTour(){
        try {
            String tourname = this.selectedTour.getName();
            tourData.removeIf(s -> s.getName().equals(tourname));
            tourNamen.removeIf(s -> s.equals(tourname));
        }catch (NullPointerException e){
            LogHelper.error(ConfigHelper.getIniString(ConfigHelper.getStandartConfig(), "langde", "keinetourselected"),
                    ConfigHelper.getIniString(ConfigHelper.getStandartConfig(), "langde", "deltournoselect"));
            AlertHelper.warn(ConfigHelper.getIniString(ConfigHelper.getStandartConfig(), "langde", "achtung"),
                    ConfigHelper.getIniString(ConfigHelper.getStandartConfig(), "langde", "keinetourselected"),
                    ConfigHelper.getIniString(ConfigHelper.getStandartConfig(), "langde", "deltournoselectmsg"));
        }
    }

    /**
     * Sucht eine Tour
     */
    public void suche(String suchString){

    }
}
